
% to run this demo, you need cvx on your matlab
% the function 'spectMixGen' belongs to Prof. Jose Bioucas-Dias

% the algorithm can be found in the paper
% X. Fu, W.-K. Ma, T.-H. Chan, and J. M. Bioucas-Dias, 
% "Self-dictionary sparse regression for hyperspectral unmixing: Greedy
% pursuit and pure pixel search are related,"  IEEE Journal of Selected Topics on Signal Processing.


clear; 
clc;



Bands = 224;
N = 6;
A = rand(Bands,N); % randomly generate the signatures



%--------------------------------------------------------------------------
%        SELECTED PARAMETERS FOR AN EASY PROBLEM
%-------------------------------------------------------------------------
A = A(:,1:N);
L = 5000;                   % number of pixels
SNR = 35;                   % signal-to-noise ratio (E ||y||^2/E ||n||^2) in dBs
SHAPE_PARAMETER  = 1   ;    % uniform over the simplex
MAX_PURIRY = 1;             % there are pure pixels in the data set
OUTLIERS  = 0;              % Number of outliers in the data set


%-------------- non-uniform noise -------------------------
[X,s,noise] = spectMixGen(A,L,'Source_pdf', 'Diri_id','pdf_pars',SHAPE_PARAMETER,...
    'max_purity',MAX_PURIRY*ones(1,N),'no_outliers',OUTLIERS, ...
    'violation_extremes',[1,1.2],'snr', SNR, ...
    'noise_shape','gaussian','noise_pars', [1,112,36],'pure_pixels','yes' );

indest_true = [L-N+1:L]; % the indices of endmembers

disp(['the number of endmembers is ',num2str(N)])
disp(['the indices of endmembers are ',num2str(indest_true)])

disp('==============================================')

[A_est,ind_est,N_est] = Lq_SD_SOMP_mod(X,'stop_crit','auto','N_max',50);

disp(['the estimated number of endmembers is ',num2str(N_est)])
disp(['the selected indices of endmembers are ',num2str(sort(ind_est,'ascend'))])